@@ -4,7 +4,7 @@
 #' @import methods
 #' @export Zelig-logit
 #' @exportClass Zelig-logit
-#' 
+#'
 #' @include model-zelig.R
 #' @include model-gee.R
 #' @include model-gamma.R
@@ -14,28 +14,22 @@
 
 zlogit <- setRefClass("Zelig-logit",
                       contains = "Zelig-binchoice")
-  
-zlogit$methods(
-  initialize = function() {
+
+zlogit$methods(initialize = function() {
     callSuper()
     .self$name <- "logit"
     .self$link <- "logit"
     .self$description = "Logistic Regression for Dichotomous Dependent Variables"
     .self$packageauthors <- "R Core Team"
     .self$wrapper <- "logit"
-  }
-)
+})
 
-
-zlogit$methods(
-  mcfun = function(x, b0=0, b1=1, ..., sim=TRUE){
+zlogit$methods(mcfun = function(x, b0 = 0, b1 = 1, ..., sim = TRUE) {
     mu <- 1/(1 + exp(-b0 - b1 * x))
-    if(sim){
-        y <- rbinom(n=length(x), size=1, prob=mu)
+    if (sim) {
+        y <- rbinom(n = length(x), size = 1, prob = mu)
         return(y)
-    }else{
+    } else {
         return(mu)
     }
-  }
-)
-
+})
