@@ -34,7 +34,7 @@ znegbin$methods(
     .self$zelig.call <- match.call(expand.dots = TRUE)
     .self$model.call <- .self$zelig.call
     callSuper(formula=formula, data=data, ..., weights=weights, by = by, bootstrap = bootstrap)
-    rse<-plyr::llply(.self$zelig.out$z.out, (function(x) vcovHC(x,type="HC0")))
+    rse <- lapply(.self$zelig.out$z.out, (function(x) vcovHC(x, type = "HC0")))
     .self$test.statistics<- list(robust.se = rse)
   }
 )
@@ -80,4 +80,3 @@ znegbin$methods(
     }
   }
 )
-
