@@ -4,7 +4,7 @@ test_that('ls wrapper continuous covar -- quickstart (Zelig 4 syntax)', {
     z4 <- zelig(Fertility ~ Education, data = swiss, model = 'ls', cite = FALSE)
   
     # extract education coefficient parameter estimate and compare to reference
-    expect_equivalent(round(as.numeric(z4$getcoef()[[1]][2]), 7), -0.8623503)
+    expect_equivalent(round(as.numeric(z4$get_coef()[[1]][2]), 7), -0.8623503)
 })
 
 # Test missing model argument error---------------------------------------------
@@ -23,9 +23,9 @@ test_that('non-supported model type error', {
   )
 })
 
-# Test wrapper setx-------------------------------------------------------------
+# REQUIRE TEST wrapper setx ----------------------------------------------------
 
-test_that('setx wrapper test x', {
+test_that('REQUIRE TEST wrapper setx', {
     z4 <- zelig(Fertility ~ Education, data = swiss, model = 'ls')
   
     z4_set <- setx(z4)
@@ -33,29 +33,33 @@ test_that('setx wrapper test x', {
     expect_equivalent(z4_set_vector, c(1, 1, 11))
 })
 
+# REQUIRE TEST wrapper setx1 ----------------------------------------------------
+
+test_that('REQUIRE TEST wrapper setx1', {
+zpipe <- zelig(Fertility ~ Education, data = swiss, model = 'ls') %>%
+                setx(z4, Education = 10) %>%
+                setx1(z4, Education = 30) %>%
+                sim() 
+    expect_equal(length(zpipe$sim.out), 2)
+
+})
+
 # FAIL TEST non-zelig objects --------------------------------------------------
 test_that('setx and sim non-zelig object fail', {
     expect_error(setx('TEST'), 'Not a Zelig object.')
     expect_error(sim('TEST'), 'Not a Zelig object.')
 })
 
-# REQUIRE TEST sim wraper minimal working --------------------------------------
+# REQUIRE TEST sim wrapper minimal working --------------------------------------
 test_that('REQUIRE TEST sim wraper minimal working', {
     z5 <- zls$new()
     z5 <- zelig(Fertility ~ Education, data = swiss, model = 'ls')
     set_x <- setx(z5, Education = 5)
   
     zsimwrap <- sim(z5, x = set_x, num = 10)
-    expect_equal(length(zsimwrap$getqi()), 10)
+    expect_equal(length(zsimwrap$get_qi()), 10)
     
     z5$setx(Education = 5)
     zsimwrap <- sim(z5, num = 10)
-    expect_equal(length(zsimwrap$getqi()), 10)
+    expect_equal(length(zsimwrap$get_qi()), 10)
 })
-
-# REQUIRE TEST from_zelig_model returns expected fitted model object -----------------
-test_that('REQUIRE TEST from_zelig_model returns expected fitted model object', {
-    z5 <- zls$new()
-    z5$zelig(Fertility ~ Education, data = swiss)
-    expect_is(from_zelig_model(z5), class = 'lm')
-})
\ No newline at end of file
